@@ -2996,14 +2996,12 @@ public:
 			throw f;
 		}
 
-		if (size == 0) {
-			*retval = xmlrpc_c::value_bytestring("");
-//			*retval = xmlrpc_c::value_bytestring("empty rx buffer!");
-		} else {
-			vector<unsigned char> bytes(size);
+		vector<unsigned char> bytes;
+		if (size) {
+			bytes.resize(size, 0);
 			memcpy(&bytes[0], text, size);
-			*retval = xmlrpc_c::value_bytestring(bytes);
 		}
+			*retval = xmlrpc_c::value_bytestring(bytes);
 LOG_VERBOSE("Text.get_rx: %s", text);
 		free(text);
 	}
@@ -3130,14 +3128,13 @@ public:
 		int size;
 		REQ_SYNC(get_rxtx, &text, &size);
 
-		if (size == 0) {
-			*retval = xmlrpc_c::value_bytestring("");
-		} else {
-			vector<unsigned char> bytes(size);
+		vector<unsigned char> bytes;
+		if (size) {
+			bytes.resize(size, 0);
 			memcpy(&bytes[0], text, size);
-			*retval = xmlrpc_c::value_bytestring(bytes);
 		}
 LOG_VERBOSE("RXTX.get_data: %s", text);
+		*retval = xmlrpc_c::value_bytestring(bytes);
 	}
 };
 
@@ -3164,14 +3161,13 @@ public:
 		int size;
 		REQ_SYNC(get_rx, &text, &size);
 
-		if (size == 0) {
-			*retval = xmlrpc_c::value_bytestring("");
-		} else {
-			vector<unsigned char> bytes(size);
+		vector<unsigned char> bytes;
+		if (size) {
+			bytes.resize(size, 0);
 			memcpy(&bytes[0], text, size);
-			*retval = xmlrpc_c::value_bytestring(bytes);
 		}
 LOG_VERBOSE("RX.get_data: %s", text);
+		*retval = xmlrpc_c::value_bytestring(bytes);
 	}
 };
 
@@ -3198,14 +3194,13 @@ public:
 		int size;
 		REQ_SYNC(get_tx, &text, &size);
 
-		if (size == 0) {
-			*retval = xmlrpc_c::value_bytestring("");
-		} else {
-			vector<unsigned char> bytes(size);
+		vector<unsigned char> bytes;
+		if (size) {
+			bytes.resize(size, 0);
 			memcpy(&bytes[0], text, size);
-			*retval = xmlrpc_c::value_bytestring(bytes);
 		}
 LOG_VERBOSE("TX.get_data: %s", text);
+		*retval = xmlrpc_c::value_bytestring(bytes);
 	}
 };
 
